# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.1.7](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.6...rattler_virtual_packages-v1.1.7) - 2024-10-07

### Other

- add snapshot tests to verify solver sorting order ([#895](https://github.com/conda/rattler/pull/895))

## [1.1.6](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.5...rattler_virtual_packages-v1.1.6) - 2024-10-03

### Other

- updated the following local packages: rattler_conda_types

## [1.1.5](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.4...rattler_virtual_packages-v1.1.5) - 2024-09-23

### Other

- updated the following local packages: rattler_conda_types

## [1.1.4](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.3...rattler_virtual_packages-v1.1.4) - 2024-09-09

### Other

- updated the following local packages: rattler_conda_types

## [1.1.3](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.2...rattler_virtual_packages-v1.1.3) - 2024-09-05

### Fixed
- typos ([#849](https://github.com/conda/rattler/pull/849))

## [1.1.2](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.1...rattler_virtual_packages-v1.1.2) - 2024-09-03

### Fixed
- allow `gcs://` and `oci://` in gateway ([#845](https://github.com/conda/rattler/pull/845))

## [1.1.1](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.1.0...rattler_virtual_packages-v1.1.1) - 2024-09-03

### Other
- updated the following local packages: rattler_conda_types

## [1.1.0](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.0.4...rattler_virtual_packages-v1.1.0) - 2024-09-02

### Added
- start adding interface to override ([#834](https://github.com/conda/rattler/pull/834))
- Add support for `CONDA_OVERRIDE_CUDA` ([#818](https://github.com/conda/rattler/pull/818))

### Other
- make virtual package overrides none by default consistently ([#842](https://github.com/conda/rattler/pull/842))

## [1.0.4](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.0.3...rattler_virtual_packages-v1.0.4) - 2024-08-16

### Fixed
- detect solus glibc ([#821](https://github.com/conda/rattler/pull/821))

## [1.0.3](https://github.com/conda/rattler/compare/rattler_virtual_packages-v1.0.2...rattler_virtual_packages-v1.0.3) - 2024-08-15

### Fixed
- move more links to the conda org from conda-incubator ([#816](https://github.com/conda/rattler/pull/816))

### Other
- change links from conda-incubator to conda ([#813](https://github.com/conda/rattler/pull/813))
- update banner ([#808](https://github.com/conda/rattler/pull/808))

## [1.0.2](https://github.com/baszalmstra/rattler/compare/rattler_virtual_packages-v1.0.1...rattler_virtual_packages-v1.0.2) - 2024-08-06

### Other
- updated the following local packages: rattler_conda_types

## [1.0.1](https://github.com/baszalmstra/rattler/compare/rattler_virtual_packages-v1.0.0...rattler_virtual_packages-v1.0.1) - 2024-08-02

### Other
- updated the following local packages: rattler_conda_types

## [0.19.20](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.19...rattler_virtual_packages-v0.19.20) - 2024-07-23

### Other
- updated the following local packages: rattler_conda_types

## [0.19.19](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.18...rattler_virtual_packages-v0.19.19) - 2024-07-23

### Other
- updated the following local packages: rattler_conda_types

## [0.19.18](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.17...rattler_virtual_packages-v0.19.18) - 2024-07-16

### Fixed
- add gentoo support for glibc ([#779](https://github.com/conda/rattler/pull/779))

## [0.19.17](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.16...rattler_virtual_packages-v0.19.17) - 2024-07-15

### Other
- updated the following local packages: rattler_conda_types

## [0.19.16](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.15...rattler_virtual_packages-v0.19.16) - 2024-07-08

### Added
- add support for zos-z ([#753](https://github.com/conda/rattler/pull/753))

### Fixed
- run clippy on all targets ([#762](https://github.com/conda/rattler/pull/762))

## [0.19.15](https://github.com/baszalmstra/rattler/compare/rattler_virtual_packages-v0.19.14...rattler_virtual_packages-v0.19.15) - 2024-06-04

### Other
- updated the following local packages: rattler_conda_types

## [0.19.14](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.13...rattler_virtual_packages-v0.19.14) - 2024-06-03

### Other
- updated the following local packages: rattler_conda_types

## [0.19.13](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.12...rattler_virtual_packages-v0.19.13) - 2024-05-28

### Other
- updated the following local packages: rattler_conda_types

## [0.19.12](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.11...rattler_virtual_packages-v0.19.12) - 2024-05-27

### Other
- updated the following local packages: rattler_conda_types

## [0.19.11](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.10...rattler_virtual_packages-v0.19.11) - 2024-05-14

### Other
- updated the following local packages: rattler_conda_types

## [0.19.10](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.9...rattler_virtual_packages-v0.19.10) - 2024-05-13

### Other
- updated the following local packages: rattler_conda_types

## [0.19.9](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.8...rattler_virtual_packages-v0.19.9) - 2024-05-06

### Other
- updated the following local packages: rattler_conda_types

## [0.19.8](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.7...rattler_virtual_packages-v0.19.8) - 2024-04-25

### Other
- updated the following local packages: rattler_conda_types

## [0.19.7](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.6...rattler_virtual_packages-v0.19.7) - 2024-04-19

### Other
- update dependencies incl. reqwest ([#606](https://github.com/conda/rattler/pull/606))

## [0.19.6](https://github.com/baszalmstra/rattler/compare/rattler_virtual_packages-v0.19.5...rattler_virtual_packages-v0.19.6) - 2024-04-05

### Other
- updated the following local packages: rattler_conda_types

## [0.19.5](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.4...rattler_virtual_packages-v0.19.5) - 2024-03-30

### Added
- proper archspec detection using archspec-rs ([#584](https://github.com/conda/rattler/pull/584))

## [0.19.4](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.3...rattler_virtual_packages-v0.19.4) - 2024-03-21

### Other
- updated the following local packages: rattler_conda_types

## [0.19.3](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.2...rattler_virtual_packages-v0.19.3) - 2024-03-14

### Other
- add pixi badge ([#563](https://github.com/conda/rattler/pull/563))

## [0.19.2](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.1...rattler_virtual_packages-v0.19.2) - 2024-03-08

### Other
- updated the following local packages: rattler_conda_types

## [0.19.1](https://github.com/conda/rattler/compare/rattler_virtual_packages-v0.19.0...rattler_virtual_packages-v0.19.1) - 2024-03-06

### Fixed
- dont use workspace dependencies for local crates ([#546](https://github.com/conda/rattler/pull/546))

### Other
- every crate should have its own version ([#557](https://github.com/conda/rattler/pull/557))

## [0.19.0](https://github.com/baszalmstra/rattler/compare/rattler_virtual_packages-v0.18.0...rattler_virtual_packages-v0.19.0) - 2024-02-26
